@@ -5,14 +5,20 @@
 #ifndef CC_PAINT_PAINT_OP_READER_H_
 #define CC_PAINT_PAINT_OP_READER_H_
 
+#include <optional>
+#include <type_traits>
+#include <vector>
+
 #include "base/bits.h"
-#include "base/memory/raw_ref.h"
+#include "base/containers/span.h"
 #include "base/memory/scoped_refptr.h"
+#include "base/memory/stack_allocated.h"
+#include "cc/paint/draw_looper.h"
 #include "cc/paint/paint_export.h"
 #include "cc/paint/paint_filter.h"
 #include "cc/paint/paint_op_writer.h"
 #include "cc/paint/transfer_cache_deserialize_helper.h"
-#include "third_party/abseil-cpp/absl/types/optional.h"
+#include "third_party/skia/include/effects/SkGradientShader.h"
 
 struct SkGainmapInfo;
 struct SkHighContrastConfig;
@@ -32,11 +38,14 @@ struct HDRMetadata;
 namespace cc {
 
 class PaintShader;
+class PathEffect;
 class SkottieWrapper;
 
 // PaintOpReader takes garbage |memory| and clobbers it with successive
 // read functions.
 class CC_PAINT_EXPORT PaintOpReader {
+  STACK_ALLOCATED();
+
  public:
   // The DeserializeOptions passed to the reader must set all fields if it can
   // be used to for deserializing images, paint records or text blobs.
@@ -60,7 +69,7 @@ class CC_PAINT_EXPORT PaintOpReader {
   bool valid() const { return valid_; }
   size_t remaining_bytes() const { return remaining_bytes_; }
 
-  void ReadData(size_t bytes, void* data);
+  void ReadData(base::span<uint8_t> data);
   void ReadSize(size_t* size);
 
   void Read(SkScalar* data);
@@ -75,9 +84,12 @@ class CC_PAINT_EXPORT PaintOpReader {
 
   void Read(SkPath* path);
   void Read(PaintFlags* flags);
-  void Read(PaintImage* image);
+  void Read(CorePaintFlags* flags);
+  void Read(PaintImage* image,
+            PaintFlags::DynamicRangeLimitMixture dynamic_range_limit);
   void Read(sk_sp<SkData>* data);
   void Read(sk_sp<sktext::gpu::Slug>* slug);
+  void Read(sk_sp<DrawLooper>* looper);
   void Read(sk_sp<PaintFilter>* filter);
   void Read(sk_sp<PaintShader>* shader);
   void Read(SkMatrix* matrix);
@@ -92,13 +104,14 @@ class CC_PAINT_EXPORT PaintOpReader {
   void Read(gpu::Mailbox* mailbox);
   void Read(SkHighContrastConfig* config);
   void Read(gfx::HDRMetadata* hdr_metadata);
+  void Read(SkGradientShader::Interpolation* interpolation);
 
   void Read(scoped_refptr<SkottieWrapper>* skottie);
 
   void Read(SkClipOp* op) { ReadEnum<SkClipOp, SkClipOp::kMax_EnumValue>(op); }
   void Read(PaintCanvas::AnnotationType* type) {
     ReadEnum<PaintCanvas::AnnotationType,
-             PaintCanvas::AnnotationType::LINK_TO_DESTINATION>(type);
+             PaintCanvas::AnnotationType::kLinkToDestination>(type);
   }
   void Read(SkCanvas::SrcRectConstraint* constraint) {
     ReadEnum<SkCanvas::SrcRectConstraint, SkCanvas::kFast_SrcRectConstraint>(
@@ -130,6 +143,28 @@ class CC_PAINT_EXPORT PaintOpReader {
     *data = !!value;
   }
 
+  // Returns true if there is enough data to read for the specified vector. If
+  // there is not enough data, the PaintOpReader is marked invalid.
+  template <typename T>
+  bool CanReadVector(size_t size, const std::vector<T>& vec) {
+    if (size > vec.max_size() || remaining_bytes_ < size * sizeof(T))
+        [[unlikely]] {
+      SetInvalid(DeserializationError::kInsufficientRemainingBytes_ReadData);
+      return false;
+    }
+    return true;
+  }
+
+  template <typename T>
+  void Read(std::vector<T>* vec) {
+    size_t size = 0;
+    ReadSize(&size);
+    if (!CanReadVector(size, *vec)) [[unlikely]] {
+      return;
+    }
+    ReadVectorContent(size, vec);
+  }
+
   // Returns a pointer to the next block of memory of size |bytes|, and treats
   // this memory as read (advancing the reader). Returns nullptr if |bytes|
   // would exceed the available budfer.
@@ -148,7 +183,7 @@ class CC_PAINT_EXPORT PaintOpReader {
  private:
   enum class DeserializationError {
     // Enum values must remain synchronized with PaintOpDeserializationError
-    // in tools/metrics/histograms/enums.xml.
+    // in tools/metrics/histograms/metadata/gpu/enums.xml.
     kDrawLooperForbidden = 0,
     kEnumValueOutOfRange = 1,
     kForbiddenSerializedImageType = 2,
@@ -187,7 +222,7 @@ class CC_PAINT_EXPORT PaintOpReader {
     kSharedImageOpenFailure = 35,  // Obsolete
     kSkColorFilterUnflattenFailure = 36,
     kSkColorSpaceDeserializeFailure = 37,
-    kSkDrawLooperUnflattenFailure = 38,
+    kSkDrawLooperUnflattenFailure = 38,  // Obsolete
     kSkMaskFilterUnflattenFailure = 39,
     kSkPathEffectUnflattenFailure = 40,
     kSkPathReadFromMemoryFailure = 41,
@@ -206,8 +241,9 @@ class CC_PAINT_EXPORT PaintOpReader {
     kSkGainmapInfoDeserializationFailure = 54,
     kHdrMetadataDeserializeFailure = 55,
     kNonFiniteSkColor4f = 56,
+    kInvalidSkColor4fAlpha = 57,
 
-    kMaxValue = kNonFiniteSkColor4f
+    kMaxValue = kInvalidSkColor4fAlpha
   };
 
   template <typename T>
@@ -218,11 +254,6 @@ class CC_PAINT_EXPORT PaintOpReader {
                                size_t size,
                                const SkDeserialProcs* procs);
 
-  template <typename T>
-  void ReadFlattenable(sk_sp<T>* val,
-                       Factory<T> factory,
-                       DeserializationError error_on_factory_failure);
-
   template <typename Enum, Enum kMaxValue = Enum::kMaxValue>
   void ReadEnum(Enum* enum_value) {
     static_assert(static_cast<unsigned>(kMaxValue) <= 255,
@@ -239,87 +270,104 @@ class CC_PAINT_EXPORT PaintOpReader {
   void SetInvalid(DeserializationError error);
 
   void Read(sk_sp<ColorFilter>* filter);
+  void Read(sk_sp<PathEffect>* effect);
 
   // The main entry point is Read(sk_sp<PaintFilter>* filter) which calls one of
   // the following functions depending on read type.
   void ReadColorFilterPaintFilter(
       sk_sp<PaintFilter>* filter,
-      const absl::optional<PaintFilter::CropRect>& crop_rect);
+      const std::optional<PaintFilter::CropRect>& crop_rect);
   void ReadBlurPaintFilter(
       sk_sp<PaintFilter>* filter,
-      const absl::optional<PaintFilter::CropRect>& crop_rect);
+      const std::optional<PaintFilter::CropRect>& crop_rect);
   void ReadDropShadowPaintFilter(
       sk_sp<PaintFilter>* filter,
-      const absl::optional<PaintFilter::CropRect>& crop_rect);
+      const std::optional<PaintFilter::CropRect>& crop_rect);
   void ReadMagnifierPaintFilter(
       sk_sp<PaintFilter>* filter,
-      const absl::optional<PaintFilter::CropRect>& crop_rect);
+      const std::optional<PaintFilter::CropRect>& crop_rect);
   void ReadComposePaintFilter(
       sk_sp<PaintFilter>* filter,
-      const absl::optional<PaintFilter::CropRect>& crop_rect);
+      const std::optional<PaintFilter::CropRect>& crop_rect);
   void ReadAlphaThresholdPaintFilter(
       sk_sp<PaintFilter>* filter,
-      const absl::optional<PaintFilter::CropRect>& crop_rect);
+      const std::optional<PaintFilter::CropRect>& crop_rect);
   void ReadXfermodePaintFilter(
       sk_sp<PaintFilter>* filter,
-      const absl::optional<PaintFilter::CropRect>& crop_rect);
+      const std::optional<PaintFilter::CropRect>& crop_rect);
   void ReadArithmeticPaintFilter(
       sk_sp<PaintFilter>* filter,
-      const absl::optional<PaintFilter::CropRect>& crop_rect);
+      const std::optional<PaintFilter::CropRect>& crop_rect);
   void ReadMatrixConvolutionPaintFilter(
       sk_sp<PaintFilter>* filter,
-      const absl::optional<PaintFilter::CropRect>& crop_rect);
+      const std::optional<PaintFilter::CropRect>& crop_rect);
   void ReadDisplacementMapEffectPaintFilter(
       sk_sp<PaintFilter>* filter,
-      const absl::optional<PaintFilter::CropRect>& crop_rect);
+      const std::optional<PaintFilter::CropRect>& crop_rect);
   void ReadImagePaintFilter(
       sk_sp<PaintFilter>* filter,
-      const absl::optional<PaintFilter::CropRect>& crop_rect);
+      const std::optional<PaintFilter::CropRect>& crop_rect);
   void ReadRecordPaintFilter(
       sk_sp<PaintFilter>* filter,
-      const absl::optional<PaintFilter::CropRect>& crop_rect);
+      const std::optional<PaintFilter::CropRect>& crop_rect);
   void ReadMergePaintFilter(
       sk_sp<PaintFilter>* filter,
-      const absl::optional<PaintFilter::CropRect>& crop_rect);
+      const std::optional<PaintFilter::CropRect>& crop_rect);
   void ReadMorphologyPaintFilter(
       sk_sp<PaintFilter>* filter,
-      const absl::optional<PaintFilter::CropRect>& crop_rect);
+      const std::optional<PaintFilter::CropRect>& crop_rect);
   void ReadOffsetPaintFilter(
       sk_sp<PaintFilter>* filter,
-      const absl::optional<PaintFilter::CropRect>& crop_rect);
+      const std::optional<PaintFilter::CropRect>& crop_rect);
   void ReadTilePaintFilter(
       sk_sp<PaintFilter>* filter,
-      const absl::optional<PaintFilter::CropRect>& crop_rect);
+      const std::optional<PaintFilter::CropRect>& crop_rect);
   void ReadTurbulencePaintFilter(
       sk_sp<PaintFilter>* filter,
-      const absl::optional<PaintFilter::CropRect>& crop_rect);
+      const std::optional<PaintFilter::CropRect>& crop_rect);
   void ReadShaderPaintFilter(
       sk_sp<PaintFilter>* filter,
-      const absl::optional<PaintFilter::CropRect>& crop_rect);
+      const std::optional<PaintFilter::CropRect>& crop_rect);
   void ReadMatrixPaintFilter(
       sk_sp<PaintFilter>* filter,
-      const absl::optional<PaintFilter::CropRect>& crop_rect);
+      const std::optional<PaintFilter::CropRect>& crop_rect);
   void ReadLightingDistantPaintFilter(
       sk_sp<PaintFilter>* filter,
-      const absl::optional<PaintFilter::CropRect>& crop_rect);
+      const std::optional<PaintFilter::CropRect>& crop_rect);
   void ReadLightingPointPaintFilter(
       sk_sp<PaintFilter>* filter,
-      const absl::optional<PaintFilter::CropRect>& crop_rect);
+      const std::optional<PaintFilter::CropRect>& crop_rect);
   void ReadLightingSpotPaintFilter(
       sk_sp<PaintFilter>* filter,
-      const absl::optional<PaintFilter::CropRect>& crop_rect);
+      const std::optional<PaintFilter::CropRect>& crop_rect);
 
   // Returns the size of the read record, 0 if error.
-  size_t Read(absl::optional<PaintRecord>* record);
+  size_t Read(std::optional<PaintRecord>* record);
 
   void Read(SkRegion* region);
   uint8_t* CopyScratchSpace(size_t bytes);
   void DidRead(size_t bytes_read);
 
-  const volatile char* memory_ = nullptr;
+  template <typename T>
+    requires(std::is_trivially_copyable_v<T>)
+  void ReadVectorContent(size_t size, std::vector<T>* vec) {
+    vec->resize(size);
+    ReadData(base::as_writable_byte_span(*vec));
+  }
+
+  template <typename T>
+    requires(!std::is_trivially_copyable_v<T>)
+  void ReadVectorContent(size_t size, std::vector<T>* vec) {
+    vec->resize(size);
+    for (size_t i = 0; i < size; ++i) {
+      Read(&(*vec)[i]);
+    }
+  }
+
+  const volatile uint8_t* memory_ = nullptr;
   size_t remaining_bytes_ = 0u;
   bool valid_ = true;
-  const raw_ref<const PaintOp::DeserializeOptions> options_;
+  const PaintOp::DeserializeOptions& options_;
 
   // Indicates that the data was serialized with the following constraints:
   // 1) PaintRecords and SkDrawLoopers are ignored.
